@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (C) 2011 Radim Rehurek <radimrehurek@seznam.cz>
-# Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
+# Licensed under the GNU LGPL v2.1 - https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 
 """Math helper functions."""
 
@@ -17,10 +17,13 @@ from gensim import utils
 import numpy as np
 import scipy.sparse
 from scipy.stats import entropy
-import scipy.linalg
+from scipy.linalg import get_blas_funcs
 from scipy.linalg.lapack import get_lapack_funcs
-from scipy.linalg.special_matrices import triu
 from scipy.special import psi  # gamma function utils
+try:
+    from numpy import triu
+except ImportError:
+    from scipy.linalg import triu
 
 
 logger = logging.getLogger(__name__)
@@ -42,7 +45,7 @@ def blas(name, ndarray):
         BLAS function for the needed operation on the given data type.
 
     """
-    return scipy.linalg.get_blas_funcs((name,), (ndarray,))[0]
+    return get_blas_funcs((name,), (ndarray,))[0]
 
 
 def argsort(x, topn=None, reverse=False):
